@@ -8,7 +8,10 @@ Description  :
 FilePath     : \execdata\format\_format_data.py
 Copyright (c) 2023 by BDFD, All Rights Reserved. 
 '''
+import execdata as exe
 
 
 def fill_zeros(num, full_position=2):
+    # exe.format.convint(num)
     result = str(num).zfill(full_position)
+    return result
